@@ -73,8 +73,16 @@ class NMFCentralizer:
         self._learning_rate = 0.1
         self._err = 1
         self._niter = 0
+        self._perf_log = pd.DataFrame(index=[], columns=self.get_logcolumns())
         return
 
+    @staticmethod
+    def get_logcolumns():
+        return ["Error before", "Last client", "Client error", "Client error delta", "Error after", "Error delta"]
+
+    def get_perf_log(self):
+        return self._perf_log
+
     def reset(self):
         self._current_h = pd.DataFrame(index=range(self._nfeat),
                                        columns=range(self._nmfcomp),
@@ -105,6 +113,7 @@ class NMFCentralizer:
 
     def request_for_update(self, client: NMFClient):
         client.update_h(self._current_h)
+        err_before = self._err
         h = client.get_latest_h()
         err_clt = client.get_latest_error()
         w_clt = math.exp(- self._learning_rate * err_clt)
@@ -113,7 +122,16 @@ class NMFCentralizer:
         self._current_h.columns = h.columns
         self._current_h = w_clt * h + w_self * self._current_h
         self._current_h = self._current_h / (w_clt + w_self)
-        self._err = (w_clt * err_clt + w_self * self._err) / (w_clt + w_self)
+        self._err = (w_clt * err_clt + w_self * err_before) / (w_clt + w_self)
+
+        log_line = pd.DataFrame(index=[self._niter], columns=self.get_logcolumns())
+        log_line.loc[self._niter, "Last client"] = client.get_name()
+        log_line.loc[self._niter, "Err before"] = err_before
+        log_line.loc[self._niter, "Client error"] = err_clt
+        log_line.loc[self._niter, "Client error delta"] = client.get_latest_error_delta()
+        log_line.loc[self._niter, "Err before"] = err_before
+        log_line.loc[self._niter, "Err delta"] = self._err - err_before
+        self._perf_log = pd.concat([self._perf_log, log_line], axis=0)
         self._niter += 1
         pass
 
@@ -183,5 +201,7 @@ class FederatedNMFConfig:
         for clt in self._clients:
             clt.reset()
 
+    def get_perf_log(self):
+        return self._nmfcentral.get_perf_log()
 
 
