@@ -323,17 +323,17 @@ def center_by_columns(mat):
     return centered_mat
 
 
-def normalize_by_columns(mat):
+def normalize_by_columns(mat, make_positive: bool = True):
     if type(mat) is not pd.DataFrame:
         cols = list(["F" + str(x) for x in range(1, mat.shape[1] + 1)])
         mat = pd.DataFrame(data=mat.values, columns=cols)
     normalized_mat = mat.copy()
-    means = np.nanmean(normalized_mat, axis=0)
-    stdevs = np.nanstd(normalized_mat, axis=0)
-    normalized_mat -= means
-    normalized_mat /= stdevs
+    add_constants = np.nanmin(normalized_mat, axis=0) if make_positive else np.nanmean(normalized_mat, axis=0)
+    mult_constants = np.nanstd(normalized_mat, axis=0)
+    normalized_mat -= add_constants
+    normalized_mat /= mult_constants
 
-    return normalized_mat, means, stdevs
+    return normalized_mat, add_constants, mult_constants
 
 
 def denormalize_by_columns(mat, means=0, stdevs=1):
